mem

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Unlock

func Unlock() error

Unlock releases memory locks if they were applied

Types

type ProtectionLevel

type ProtectionLevel int

ProtectionLevel indicates how well the vault can protect memory

const (
	ProtectionNone    ProtectionLevel = iota // No memory protection available
	ProtectionPartial                        // Some protection measures applied
	ProtectionFull                           // Full memory protection (locked memory)
)

func Lock

func Lock() (ProtectionLevel, error)

Lock attempts to prevent sensitive data from being swapped to disk Returns the protection level achieved and any error encountered

Jump to